import * as React from 'react';
import { NextApiResponse } from '../../common';

export const useResponse = (res: NextApiResponse) => {
	const [response, setResponse] = React.useState<Response | undefined>(
		res.body ? new Response(res.body as unknown as BodyInit) : undefined,
	);

	const invalidate = React.useCallback(() => {
		setResponse(undefined);
	}, []);

	const refresh = React.useCallback((newResponse: Response) => {
		setResponse(newResponse);
	}, []);

	return React.useMemo(() => ({
		response,
		refresh,
		invalidate,
	}), [
		response,
		refresh,
		invalidate,
	]);
};
